xpcs\_toolkit.simplemask package
================================

Mask editing and Q-map generation module for XPCS analysis.

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xpcs_toolkit.simplemask.ui

Submodules
----------

xpcs\_toolkit.simplemask.simplemask\_window module
--------------------------------------------------

.. automodule:: xpcsviewer.simplemask.simplemask_window
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.simplemask.simplemask\_kernel module
--------------------------------------------------

.. automodule:: xpcsviewer.simplemask.simplemask_kernel
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.simplemask.qmap module
------------------------------------

.. automodule:: xpcsviewer.simplemask.qmap
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.simplemask.area\_mask module
------------------------------------------

.. automodule:: xpcsviewer.simplemask.area_mask
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.simplemask.drawing\_tools module
----------------------------------------------

.. automodule:: xpcsviewer.simplemask.drawing_tools
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.simplemask.utils module
-------------------------------------

.. automodule:: xpcsviewer.simplemask.utils
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.simplemask.pyqtgraph\_mod module
----------------------------------------------

.. automodule:: xpcsviewer.simplemask.pyqtgraph_mod
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: xpcsviewer.simplemask
   :members:
   :undoc-members:
   :show-inheritance:
